package com.usky.dxtop.controller.web;


import com.usky.dxtop.common.annotation.RepeatSubmit;
import com.usky.dxtop.common.constant.UserConstants;
import com.usky.dxtop.common.core.domain.AjaxResult;
import com.usky.dxtop.common.utils.SecurityUtils;
import com.usky.dxtop.controller.BaseController;
import com.usky.dxtop.model.TopRadio;
import com.usky.dxtop.service.TopRadioService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * 充值到账比例
 *
 * @author yq
 * @since 2021-08-26
 */
@RestController
@RequestMapping("/dxtop/topRadio")
public class TopRadioController extends BaseController {

    @Autowired
    private TopRadioService topRadioService;

    /**
     * 新增
     * @param topRadio
     * @return
     */
    @RepeatSubmit
    @PostMapping
    public AjaxResult add(@Validated @RequestBody TopRadio topRadio){
        if (UserConstants.NOT_UNIQUE.equals(topRadioService.checkIdentityUnique(topRadio)))
        {
            return AjaxResult.error("新增身份信息'" + topRadio.getIdentity() + "'失败，身份信息已存在");
        }
        topRadio.setCreateBy(SecurityUtils.getUsername());
        return toAjax(topRadioService.save(topRadio));

    }

    /**
     * 修改
     */
    @PutMapping
    public AjaxResult edit(@Validated @RequestBody TopRadio topRadio)
    {
        if (UserConstants.NOT_UNIQUE.equals(topRadioService.checkIdentityUnique(topRadio)))
        {
            return AjaxResult.error("修改身份信息'" + topRadio.getIdentity() + "'失败，身份信息已存在");
        }
        topRadio.setUpdateBy(SecurityUtils.getUsername());
        return toAjax(topRadioService.updateById(topRadio));
    }

    /**
     * 分页
     * @param
     * @return
     */
    @GetMapping("/list")
    public AjaxResult list(@RequestParam Integer current,
                           @RequestParam Integer size,
                           @RequestParam(required = false) String identity)
    {
        return AjaxResult.success(topRadioService.list(current, size, identity));
    }


    /**
     * 删除
     */
    @DeleteMapping("/{id}")
    public AjaxResult remove(@PathVariable("id") Long id)
    {
        TopRadio topRadio = new TopRadio();
        topRadio.setId(id);
        topRadio.setDelFlag(true);
        return toAjax(topRadioService.updateById(topRadio));
    }


    @GetMapping("/all")
    public AjaxResult all(){
        return AjaxResult.success(topRadioService.list());
    }

}

