package com.usky.dxtop.service.listener;

import com.alibaba.fastjson.JSONObject;
import com.usky.dxtop.model.Dish;
import com.usky.dxtop.model.Staff;
import com.usky.dxtop.service.DishService;
import com.usky.dxtop.service.StaffService;
import com.usky.dxtop.service.config.rabbitmq.DishTransConfig;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.core.Message;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.nio.charset.StandardCharsets;

/**
 * @author yq
 * @date 2021/9/9 11:05
 */
@Slf4j
@Component
public class DishTransMqListener {

    @Autowired
    private DishService dishService;
    @Autowired
    private StaffService staffService;
    @RabbitListener(queues = DishTransConfig.NAME, containerFactory = DishTransConfig.LISTENER)
    public void dealDeclareMessage(Message message) {
        try {
            //消息类型
            String routingKey = message.getMessageProperties().getReceivedRoutingKey();
            log.info(routingKey);
            //消息内容
            String s = new String(message.getBody(), StandardCharsets.UTF_8);
            log.info("dish_trade_produce获取到的消息"+s);
            Dish dish = JSONObject.parseObject(s, Dish.class);;
            dishService.saveOrUpdate(dish);
            //更新用户余额
            Staff staff = staffService.one(null, null, dish.getCard());
            staff.setBalance(dish.getBalance());
            staffService.updateById(staff);
        } catch (Exception e) {
            log.info("dish_trade_produce"+"异常信息：" + e.getMessage());
        }
    }
}
